Continuation Module
===================

.. module:: beluga.continuation

Introduction
------------

This module handles numerical continuation in the solver.

Base Class Reference
--------------------

.. autoclass:: ContinuationList
    :members:

.. autoclass:: ContinuationVariable
    :members:

.. autoclass:: ManualStrategy
    :members:

.. autoclass:: BisectionStrategy
    :members:

.. autoclass:: HPA_Variable
    :members:
